@@ -6,12 +6,9 @@ use AsyncAws\Core\Exception\InvalidArgument;
 use AsyncAws\Core\Input;
 use AsyncAws\Core\Request;
 use AsyncAws\Core\Stream\StreamFactory;
-use AsyncAws\Ses\ValueObject\Body;
-use AsyncAws\Ses\ValueObject\Content;
 use AsyncAws\Ses\ValueObject\Destination;
 use AsyncAws\Ses\ValueObject\EmailContent;
 use AsyncAws\Ses\ValueObject\ListManagementOptions;
-use AsyncAws\Ses\ValueObject\Message;
 use AsyncAws\Ses\ValueObject\MessageTag;
 
 /**
@@ -141,18 +138,18 @@ final class SendEmailRequest extends Input
 
     /**
      * @param array{
-     *   FromEmailAddress?: null|string,
-     *   FromEmailAddressIdentityArn?: null|string,
-     *   Destination?: null|Destination|array,
-     *   ReplyToAddresses?: null|string[],
-     *   FeedbackForwardingEmailAddress?: null|string,
-     *   FeedbackForwardingEmailAddressIdentityArn?: null|string,
+     *   FromEmailAddress?: string|null,
+     *   FromEmailAddressIdentityArn?: string|null,
+     *   Destination?: Destination|array|null,
+     *   ReplyToAddresses?: string[]|null,
+     *   FeedbackForwardingEmailAddress?: string|null,
+     *   FeedbackForwardingEmailAddressIdentityArn?: string|null,
      *   Content?: EmailContent|array,
-     *   EmailTags?: null|array<MessageTag|array>,
-     *   ConfigurationSetName?: null|string,
-     *   EndpointId?: null|string,
-     *   TenantName?: null|string,
-     *   ListManagementOptions?: null|ListManagementOptions|array,
+     *   EmailTags?: array<MessageTag|array>|null,
+     *   ConfigurationSetName?: string|null,
+     *   EndpointId?: string|null,
+     *   TenantName?: string|null,
+     *   ListManagementOptions?: ListManagementOptions|array|null,
      *   '@region'?: string|null,
      * } $input
      */
@@ -175,18 +172,18 @@ final class SendEmailRequest extends Input
 
     /**
      * @param array{
-     *   FromEmailAddress?: null|string,
-     *   FromEmailAddressIdentityArn?: null|string,
-     *   Destination?: null|Destination|array,
-     *   ReplyToAddresses?: null|string[],
-     *   FeedbackForwardingEmailAddress?: null|string,
-     *   FeedbackForwardingEmailAddressIdentityArn?: null|string,
+     *   FromEmailAddress?: string|null,
+     *   FromEmailAddressIdentityArn?: string|null,
+     *   Destination?: Destination|array|null,
+     *   ReplyToAddresses?: string[]|null,
+     *   FeedbackForwardingEmailAddress?: string|null,
+     *   FeedbackForwardingEmailAddressIdentityArn?: string|null,
      *   Content?: EmailContent|array,
-     *   EmailTags?: null|array<MessageTag|array>,
-     *   ConfigurationSetName?: null|string,
-     *   EndpointId?: null|string,
-     *   TenantName?: null|string,
-     *   ListManagementOptions?: null|ListManagementOptions|array,
+     *   EmailTags?: array<MessageTag|array>|null,
+     *   ConfigurationSetName?: string|null,
+     *   EndpointId?: string|null,
+     *   TenantName?: string|null,
+     *   ListManagementOptions?: ListManagementOptions|array|null,
      *   '@region'?: string|null,
      * }|SendEmailRequest $input
      */
